@@ -1,29 +1,17 @@
-/* Copyright (C) 2014 Jesper K. Pedersen <blackie@kde.org>
+/* SPDX-FileCopyrightText: 2014 Jesper K. Pedersen <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef REMOTEIMAGE_H
 #define REMOTEIMAGE_H
 
-#include <QQuickPaintedItem>
-#include <QImage>
 #include "Types.h"
+#include <QImage>
+#include <QQuickPaintedItem>
 
-namespace RemoteControl {
+namespace RemoteControl
+{
 
 class RemoteImage : public QQuickPaintedItem
 {
@@ -37,8 +25,8 @@ public:
     void paint(QPainter *painter) override;
     int imageId() const;
     QSize size() const;
-    void setLabel(const QString& label);
-    void setImage(const QImage& image);
+    void setLabel(const QString &label);
+    void setImage(const QImage &image);
 
 public slots:
     void setImageId(int imageId);
