@@ -1,17 +1,19 @@
 // SPDX-FileCopyrightText: 2003-2019 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2020 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "CompletableLineEdit.h"
 
 #include "ListSelect.h"
-#include "ResizableFrame.h"
 
 #include <QKeyEvent>
 #include <QRegExp>
 #include <QTreeWidgetItem>
 #include <QTreeWidgetItemIterator>
+#include <kcompletion_version.h>
 
 AnnotationDialog::CompletableLineEdit::CompletableLineEdit(ListSelect *parent)
     : KLineEdit(parent)
@@ -42,7 +44,7 @@ void AnnotationDialog::CompletableLineEdit::keyPressEvent(QKeyEvent *ev)
         return;
     }
 
-    if (m_mode == SearchMode && (ev->key() == Qt::Key_Return || ev->key() == Qt::Key_Enter)) { //Confirm autocomplete, deselect all text
+    if (m_mode == SearchMode && (ev->key() == Qt::Key_Return || ev->key() == Qt::Key_Enter)) { // Confirm autocomplete, deselect all text
         handleSpecialKeysInSearch(ev);
         m_listSelect->showOnlyItemsMatching(QString()); // Show all again after confirming autocomplete suggestion.
         return;
@@ -62,7 +64,11 @@ void AnnotationDialog::CompletableLineEdit::keyPressEvent(QKeyEvent *ev)
         // If final Return is handled by the default implementation,
         // it can "leak" to other widgets. So we swallow it here:
         if (ev->key() == Qt::Key_Return || ev->key() == Qt::Key_Enter)
+#if KCOMPLETION_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+            emit KLineEdit::returnKeyPressed(text());
+#else
             emit KLineEdit::returnPressed(text());
+#endif
         else
             KLineEdit::keyPressEvent(ev);
         if (prevContent != text())
@@ -162,7 +168,7 @@ void AnnotationDialog::CompletableLineEdit::handleSpecialKeysInSearch(QKeyEvent
     setText(txt);
 
     if (!isSpecialKey(ev)) {
-        //Special handling for ENTER to position the cursor correctly
+        // Special handling for ENTER to position the cursor correctly
         setText(text().left(text().size() - 1));
         cursorPos--;
     }
