@@ -31,6 +31,7 @@
 #include <QRadioButton>
 #include <QToolButton>
 #include <QWidgetAction>
+#include <kcompletion_version.h>
 
 using namespace AnnotationDialog;
 using CategoryListView::CheckDropItem;
@@ -489,7 +490,7 @@ void AnnotationDialog::ListSelect::showContextMenu(const QPoint &pos)
         m_category->addItem(superCategory);
         memberMap.addGroup(m_category->name(), superCategory);
         memberMap.addMemberToGroup(m_category->name(), superCategory, item->text(0));
-        //DB::ImageDB::instance()->setMemberMap( memberMap );
+        // DB::ImageDB::instance()->setMemberMap( memberMap );
         rePopulate();
     } else if (which == newSubcategoryAction) {
         Q_ASSERT(item);
@@ -503,7 +504,7 @@ void AnnotationDialog::ListSelect::showContextMenu(const QPoint &pos)
         m_category->addItem(subCategory);
         memberMap.addGroup(m_category->name(), item->text(0));
         memberMap.addMemberToGroup(m_category->name(), item->text(0), subCategory);
-        //DB::ImageDB::instance()->setMemberMap( memberMap );
+        // DB::ImageDB::instance()->setMemberMap( memberMap );
         m_category->addItem(subCategory);
 
         rePopulate();
@@ -870,7 +871,11 @@ void ListSelect::connectLineEdit(CompletableLineEdit *le)
 {
     le->setObjectName(m_category->name());
     le->setListView(m_treeWidget);
+#if KCOMPLETION_VERSION >= QT_VERSION_CHECK(5, 81, 0)
+    connect(le, &KLineEdit::returnKeyPressed, this, &ListSelect::slotExternalReturn);
+#else
     connect(le, &KLineEdit::returnPressed, this, &ListSelect::slotExternalReturn);
+#endif
 }
 
 void AnnotationDialog::ListSelect::ensureTagIsSelected(QString category, QString tag)
@@ -904,3 +909,5 @@ void AnnotationDialog::ListSelect::deselectTag(QString tag)
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
+
+#include "moc_ListSelect.cpp"
