@@ -1,7 +1,8 @@
-/* SPDX-FileCopyrightText: 2012-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2012-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #ifndef EXIF_GRID_H
 #define EXIF_GRID_H
 
@@ -53,7 +54,6 @@ private slots:
 
 private:
     QList<QPair<QLabel *, QLabel *>> m_labels;
-    int m_maxKeyWidth;
     DB::FileName m_fileName;
 };
 
