@@ -1,20 +1,8 @@
-/* Copyright (C) 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
 #ifndef THUMBNAILVIEW_THUMBNAILWIDGET_H
 #define THUMBNAILVIEW_THUMBNAILWIDGET_H
 
@@ -29,7 +17,10 @@
 #include <QScopedPointer>
 
 class QTimer;
-class QDateTime;
+namespace Utilities
+{
+class FastDateTime;
+}
 
 namespace DB
 {
@@ -84,8 +75,9 @@ public slots:
 signals:
     void showImage(const DB::FileName &id);
     void showSelection();
+    void showSearch();
     void fileIdUnderCursorChanged(const DB::FileName &id);
-    void currentDateChanged(const QDateTime &);
+    void currentDateChanged(const Utilities::FastDateTime &);
     void selectionCountChanged(int numberOfItemsSelected);
 
 protected:
