@@ -1,10 +1,11 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "ImageUtil.h"
 
+#include <kpabase/Logging.h>
 #include <kpabase/SettingsData.h>
 
 #include <QDir>
@@ -20,7 +21,8 @@ void Utilities::saveImage(const DB::FileName &fileName, const QImage &image, con
     const QFileInfo info(fileName.absolute());
     QDir().mkpath(info.path());
     const bool ok = image.save(fileName.absolute(), format);
-    Q_ASSERT(ok);
-    Q_UNUSED(ok);
+    if (!ok) {
+        qCWarning(UtilitiesLog) << "Could not save image:" << fileName.absolute();
+    }
 }
 // vi:expandtab:tabstop=4 shiftwidth=4:
