@@ -8,8 +8,9 @@
 
 #include <DB/ImageInfo.h>
 #include <DB/ImageInfoPtr.h>
-#include <kpabase/FileNameList.h>
 #include <MainWindow/CopyLinkEngine.h>
+#include <kpabase/CrashSentinel.h>
+#include <kpabase/FileNameList.h>
 
 #include <QImage>
 #include <QMap>
@@ -149,9 +150,7 @@ protected slots:
     void showLast();
     void deleteCurrent();
     void removeCurrent();
-    void rotate90();
-    void rotate180();
-    void rotate270();
+    void rotate(int angle);
     void toggleFullScreen();
     void slotStartStopSlideShow();
     void slotSlideShowNext();
@@ -211,6 +210,8 @@ private:
     VideoDisplay *m_videoDisplay;
     TextDisplay *m_textDisplay;
 
+    KPABase::CrashSentinel m_crashSentinel;
+
     int m_screenSaverCookie;
     DB::FileNameList m_list;
     DB::FileNameList m_removed;
