@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -58,7 +59,7 @@ void XMLDB::FileReader::read(const QString &configFile)
     loadImages(reader);
     loadBlockList(reader);
     loadMemberGroups(reader);
-    //loadSettings(reader);
+    // loadSettings(reader);
 
     repairDB();
 
@@ -79,7 +80,9 @@ void XMLDB::FileReader::createSpecialCategories()
     if (m_db->m_categoryCollection.categoryForName(m_folderCategory->name()))
         m_db->m_categoryCollection.removeCategory(m_folderCategory->name());
     m_db->m_categoryCollection.addCategory(m_folderCategory);
-    dynamic_cast<XMLCategory *>(m_folderCategory.data())->setShouldSave(false);
+    auto xmlCategory = dynamic_cast<XMLCategory *>(m_folderCategory.data());
+    Q_ASSERT(xmlCategory);
+    xmlCategory->setShouldSave(false);
 
     // Setup the "Tokens" category
 
@@ -124,7 +127,9 @@ void XMLDB::FileReader::createSpecialCategories()
     mediaCat->addItem(i18n("Image"));
     mediaCat->addItem(i18n("Video"));
     mediaCat->setType(DB::Category::MediaTypeCategory);
-    dynamic_cast<XMLCategory *>(mediaCat.data())->setShouldSave(false);
+    auto mediaCategory = dynamic_cast<XMLCategory *>(mediaCat.data());
+    Q_ASSERT(mediaCategory);
+    mediaCategory->setShouldSave(false);
     // The media type is not stored in the media category,
     // but older versions of KPhotoAlbum stored a stub entry, which we need to remove first:
     if (m_db->m_categoryCollection.categoryForName(mediaCat->name()))
@@ -485,7 +490,7 @@ XMLDB::ReaderPtr XMLDB::FileReader::readConfigFile(const QString &configFile)
                 DB::LogMessage { XMLDBLog(), QString::fromLatin1("default-setup not found in standard paths.") },
                 i18n("<p>KPhotoAlbum was unable to load a default setup, which indicates an installation error</p>"
                      "<p>If you have installed KPhotoAlbum yourself, then you must remember to set the environment variable "
-                     "<b>KDEDIRS</b>, to point to the topmost installation directory.</p>"
+                     "<b>KDEDIRS</b>, to point to the topmost installation folder.</p>"
                      "<p>If you for example ran cmake with <b>-DCMAKE_INSTALL_PREFIX=/usr/local/kde</b>, then you must use the following "
                      "environment variable setup (this example is for Bash and compatible shells):</p>"
                      "<p><b>export KDEDIRS=/usr/local/kde</b></p>"
