@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -56,7 +57,7 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
     m_db->m_categoryCollection.initIdMap();
     QFile out(fileName + QStringLiteral(".tmp"));
     if (!out.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        m_db->uiDelegate().sorry(
+        m_db->uiDelegate().error(
             DB::LogMessage { XMLDBLog(), QStringLiteral("Error saving to file '%1': %2").arg(out.fileName()).arg(out.errorString()) }, i18n("<p>Could not save the image database to XML.</p>"
                                                                                                                                             "File %1 could not be opened because of the following error: %2",
                                                                                                                                             out.fileName(), out.errorString()),
@@ -79,7 +80,7 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
         saveImages(writer);
         saveBlockList(writer);
         saveMemberGroups(writer);
-        //saveSettings(writer);
+        // saveSettings(writer);
     }
     writer.writeEndDocument();
     qCDebug(TimingLog) << "XMLDB::FileWriter::save(): Saving took" << timer.elapsed() << "ms";
@@ -88,7 +89,7 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
 
     // original file can be safely deleted
     if ((!QFile::remove(fileName)) && QFile::exists(fileName)) {
-        m_db->uiDelegate().sorry(
+        m_db->uiDelegate().error(
             DB::LogMessage { XMLDBLog(), QStringLiteral("Removal of file '%1' failed.").arg(fileName) }, i18n("<p>Failed to remove old version of image database.</p>"
                                                                                                               "<p>Please try again or replace the file %1 with file %2 manually!</p>",
                                                                                                               fileName, out.fileName()),
@@ -97,7 +98,7 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
     }
     // State: index.xml doesn't exist, index.xml.tmp has the current version.
     if (!out.rename(fileName)) {
-        m_db->uiDelegate().sorry(
+        m_db->uiDelegate().error(
             DB::LogMessage { XMLDBLog(), QStringLiteral("Renaming index.xml to '%1' failed.").arg(out.fileName()) }, i18n("<p>Failed to move temporary XML file to permanent location.</p>"
                                                                                                                           "<p>Please try again or rename file %1 to %2 manually!</p>",
                                                                                                                           out.fileName(), fileName),
@@ -455,7 +456,9 @@ bool XMLDB::FileWriter::shouldSaveCategory(const QString &categoryName) const
         return false;
     }
 
-    const bool shouldSave = dynamic_cast<XMLCategory *>(m_db->m_categoryCollection.categoryForName(categoryName).data())->shouldSave();
+    const auto category = dynamic_cast<XMLCategory *>(m_db->m_categoryCollection.categoryForName(categoryName).data());
+    Q_ASSERT(category);
+    const bool shouldSave = category->shouldSave();
     cache.insert(categoryName, shouldSave);
     return shouldSave;
 }
